@@ -22,14 +22,14 @@ type ResolverFunc func(context *Context, parent *Path, flag *Flag) (interface{},
 
 var _ Resolver = ResolverFunc(nil)
 
-func (r ResolverFunc) Resolve(context *Context, parent *Path, flag *Flag) (interface{}, error) { // nolint: golint
+func (r ResolverFunc) Resolve(context *Context, parent *Path, flag *Flag) (interface{}, error) { // nolint: revive
 	return r(context, parent, flag)
 }
-func (r ResolverFunc) Validate(app *Application) error { return nil } //  nolint: golint
+func (r ResolverFunc) Validate(app *Application) error { return nil } // nolint: revive
 
 // JSON returns a Resolver that retrieves values from a JSON source.
 //
-// Hyphens in flag names are replaced with underscores.
+// Flag names are used as JSON keys indirectly, by tring snake_case and camelCase variants.
 func JSON(r io.Reader) (Resolver, error) {
 	values := map[string]interface{}{}
 	err := json.NewDecoder(r).Decode(&values)
@@ -37,13 +37,32 @@ func JSON(r io.Reader) (Resolver, error) {
 		return nil, err
 	}
 	var f ResolverFunc = func(context *Context, parent *Path, flag *Flag) (interface{}, error) {
-		name := strings.Replace(flag.Name, "-", "_", -1)
+		name := strings.ReplaceAll(flag.Name, "-", "_")
+		snakeCaseName := snakeCase(flag.Name)
 		raw, ok := values[name]
-		if !ok {
-			return nil, nil
+		if ok {
+			return raw, nil
+		} else if raw, ok = values[snakeCaseName]; ok {
+			return raw, nil
+		}
+		raw = values
+		for _, part := range strings.Split(name, ".") {
+			if values, ok := raw.(map[string]interface{}); ok {
+				raw, ok = values[part]
+				if !ok {
+					return nil, nil
+				}
+			} else {
+				return nil, nil
+			}
 		}
 		return raw, nil
 	}
 
 	return f, nil
 }
+
+func snakeCase(name string) string {
+	name = strings.Join(strings.Split(strings.Title(name), "-"), "") //nolint: staticcheck
+	return strings.ToLower(name[:1]) + name[1:]
+}
